@@ -93,24 +93,18 @@ class ClearCommand(BaseCommand):
         return len(files)
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
-        types: Iterable[str] = ()
         if not options.type:
-            pass
-        elif options.type not in self.CACHE_TYPES:
-            raise PdmUsageError(f"Invalid cache type {options.type}, should one of {self.CACHE_TYPES}")
+            types: Iterable[str] = self.CACHE_TYPES
         else:
             types = (str(options.type),)
 
         packages = files = 0
         with project.core.ui.open_spinner(f"Clearing {options.type or 'all'} caches..."):
-            if not options.type:
-                packages, files = 0, self._clear_files(project.cache_dir)
-            else:
-                for type_ in types:
-                    if type_ == "packages":
-                        packages += project.package_cache.cleanup()
-                    else:
-                        files += self._clear_files(project.cache(type_))
+            for type_ in types:
+                if type_ == "packages":
+                    packages += project.package_cache.cleanup()
+                else:
+                    files += self._clear_files(project.cache(type_))
             message = []
             if packages:
                 message.append(f"{packages} package{'s' if packages > 1 else ''}")
