@@ -23,18 +23,22 @@ class Command(BaseCommand):
         parser.add_argument(
             "-f",
             "--format",
-            choices=FORMATS.keys(),
+            choices=["requirements"],
             default="requirements",
-            help="Specify the export file format",
+            help="Only requirements.txt is supported for now.",
         )
         groups_group.add_to_parser(parser)
         parser.add_argument(
+            "--no-hashes",
             "--without-hashes",
             dest="hashes",
             action="store_false",
             default=True,
             help="Don't include artifact hashes",
         )
+        parser.add_argument(
+            "--no-markers", action="store_false", default=True, dest="markers", help="Don't include platform markers"
+        )
         parser.add_argument(
             "-o",
             "--output",
@@ -46,6 +50,11 @@ class Command(BaseCommand):
             help="Read the list of packages from pyproject.toml",
         )
         parser.add_argument("--expandvars", action="store_true", help="Expand environment variables in requirements")
+        group = parser.add_mutually_exclusive_group()
+        group.add_argument("--self", action="store_true", help="Include the project itself")
+        group.add_argument(
+            "--editable-self", action="store_true", help="Include the project itself as an editable dependency"
+        )
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
         if options.pyproject:
@@ -60,13 +69,10 @@ class Command(BaseCommand):
         else:
             if not project.lockfile.exists():
                 raise PdmUsageError("No lockfile found, please run `pdm lock` first.")
-            project.core.ui.echo(
-                "The exported requirements file is no longer cross-platform. "
-                "Using it on other platforms may cause unexpected result.",
-                style="warning",
-                err=True,
+
+            candidates = resolve_candidates_from_lockfile(
+                project, requirements.values(), groups=set(selection), cross_platform=options.markers
             )
-            candidates = resolve_candidates_from_lockfile(project, requirements.values())
             # Remove candidates with [extras] because the bare candidates are already
             # included
             packages = (candidate for candidate in candidates.values() if not candidate.req.extras)
