@@ -1,4 +1,5 @@
 import argparse
+import platform
 import shlex
 from pathlib import Path
 
@@ -26,19 +27,15 @@ class ActivateCommand(BaseCommand):
             # Use what is saved in .pdm-python
             interpreter = project._saved_python
             if not interpreter:
-                project.core.ui.echo(
-                    "The project doesn't have a saved python.path. Run [success]pdm use[/] to pick one.",
-                    style="warning",
-                    err=True,
+                project.core.ui.warn(
+                    "The project doesn't have a saved python.path. Run [success]pdm use[/] to pick one."
                 )
                 raise SystemExit(1)
             venv_like = VirtualEnv.from_interpreter(Path(interpreter))
             if venv_like is None:
-                project.core.ui.echo(
+                project.core.ui.warn(
                     f"Can't activate a non-venv Python [success]{interpreter}[/], "
                     "you can specify one with [success]pdm venv activate <env_name>[/]",
-                    style="warning",
-                    err=True,
                 )
                 raise SystemExit(1)
             venv = venv_like
@@ -48,7 +45,7 @@ class ActivateCommand(BaseCommand):
         try:
             shell, _ = shellingham.detect_shell()
         except shellingham.ShellDetectionFailure:
-            shell = None
+            shell = ""
         if shell == "fish":
             command, filename = "source", "activate.fish"
         elif shell == "csh":
@@ -59,6 +56,14 @@ class ActivateCommand(BaseCommand):
             command, filename = "source", "activate"
         activate_script = venv.interpreter.with_name(filename)
         if activate_script.exists():
-            return f"{command} {shlex.quote(str(activate_script))}"
+            if platform.system() == "Windows":
+                return f"{self.quote(str(activate_script), shell)}"
+            return f"{command} {self.quote(str(activate_script), shell)}"
         # Conda backed virtualenvs don't have activate scripts
-        return f"conda activate {shlex.quote(str(venv.root))}"
+        return f"conda activate {self.quote(str(venv.root), shell)}"
+
+    @staticmethod
+    def quote(command: str, shell: str) -> str:
+        if shell in ["powershell", "pwsh"]:
+            return "'{}'".format(command.replace("'", "''"))
+        return shlex.quote(command)
