@@ -54,6 +54,7 @@ _file_req_re = re.compile(
 )
 _egg_info_re = re.compile(r"([a-z0-9_.]+)-([a-z0-9_.!+-]+)", re.IGNORECASE)
 T = TypeVar("T", bound="Requirement")
+ALLOW_ANY = SpecifierSet()
 
 
 def strip_extras(line: str) -> tuple[str, tuple[str, ...] | None]:
@@ -79,7 +80,7 @@ class Requirement:
     name: str | None = None
     marker: Marker | None = None
     extras: Sequence[str] | None = None
-    specifier: SpecifierSet | None = None
+    specifier: SpecifierSet = ALLOW_ANY
     editable: bool = False
     prerelease: bool | None = None
     groups: list[str] = dataclasses.field(default_factory=list)
@@ -97,9 +98,6 @@ class Requirement:
 
     @property
     def is_pinned(self) -> bool:
-        if not self.specifier:
-            return False
-
         if len(self.specifier) != 1:
             return False
 
@@ -171,7 +169,7 @@ class Requirement:
         return NamedRequirement.create(name=dist.metadata["Name"], version=f"=={dist.version}")
 
     @classmethod
-    def from_req_dict(cls, name: str, req_dict: RequirementDict) -> Requirement:
+    def from_req_dict(cls, name: str, req_dict: RequirementDict, check_installable: bool = True) -> Requirement:
         if isinstance(req_dict, str):  # Version specifier only.
             return NamedRequirement(name=name, specifier=get_specifier(req_dict))
         for vcs in VCS_SCHEMA:
@@ -180,7 +178,7 @@ class Requirement:
                 url = f"{vcs}+{repo}"
                 return VcsRequirement.create(name=name, vcs=vcs, url=url, **req_dict)
         if "path" in req_dict or "url" in req_dict:
-            return FileRequirement.create(name=name, **req_dict)
+            return FileRequirement.create(name=name, **req_dict, check_installable=check_installable)
         return NamedRequirement.create(name=name, **req_dict)
 
     @property
@@ -243,11 +241,12 @@ class FileRequirement(Requirement):
     url: str = ""
     path: Path | None = None
     subdirectory: str | None = None
+    check_installable: bool = True
 
     def __post_init__(self) -> None:
         super().__post_init__()
         self._parse_url()
-        if self.is_local_dir:
+        if self.is_local_dir and self.check_installable:
             self._check_installable()
 
     def _hash_key(self) -> tuple:
@@ -385,6 +384,8 @@ class FileRequirement(Requirement):
 
     def _check_installable(self) -> None:
         assert self.path
+        if not self.path.exists():
+            return
         if not (self.path.joinpath("setup.py").exists() or self.path.joinpath("pyproject.toml").exists()):
             raise RequirementError(f"The local path '{self.path}' is not installable.")
         result = Setup.from_directory(self.path.absolute())
