@@ -128,12 +128,20 @@ class MsgPackSerializer(hishel.BaseSerializer):
 
 
 class PDMPyPIClient(PyPIClient):
-    def __init__(self, *, sources: list[RepositoryConfig], cache_dir: Path, **kwargs: Any) -> None:
+    def __init__(self, *, sources: list[RepositoryConfig], cache_dir: Path | None = None, **kwargs: Any) -> None:
         from httpx._utils import URLPattern
         from unearth.fetchers.sync import LocalFSTransport
 
-        storage = hishel.FileStorage(serializer=MsgPackSerializer(), base_path=cache_dir, ttl=CACHES_TTL)
-        controller = hishel.Controller()
+        if cache_dir is None:
+
+            def cache_transport(transport: httpx.BaseTransport) -> httpx.BaseTransport:
+                return transport
+        else:
+            storage = hishel.FileStorage(serializer=MsgPackSerializer(), base_path=cache_dir, ttl=CACHES_TTL)
+            controller = hishel.Controller()
+
+            def cache_transport(transport: httpx.BaseTransport) -> httpx.BaseTransport:
+                return hishel.CacheTransport(transport, storage, controller)
 
         mounts: dict[str, httpx.BaseTransport] = {"file://": LocalFSTransport()}
         self._trusted_host_ports: set[tuple[str, int | None]] = set()
@@ -148,9 +156,7 @@ class PDMPyPIClient(PyPIClient):
             if s.name == "pypi":
                 kwargs["transport"] = self._transport_for(s)
                 continue
-            mounts[f"{url.scheme}://{url.netloc.decode('ascii')}/"] = hishel.CacheTransport(
-                self._transport_for(s), storage, controller
-            )
+            mounts[f"{url.scheme}://{url.netloc.decode('ascii')}/"] = cache_transport(self._transport_for(s))
         mounts.update(kwargs.pop("mounts", None) or {})
         kwargs.update(follow_redirects=True)
 
@@ -158,7 +164,7 @@ class PDMPyPIClient(PyPIClient):
 
         self.headers["User-Agent"] = self._make_user_agent()
         self.event_hooks["response"].append(self.on_response)
-        self._transport = hishel.CacheTransport(self._transport, storage, controller)  # type: ignore[has-type]
+        self._transport = cache_transport(self._transport)  # type: ignore[has-type]
 
     def _transport_for(self, source: RepositoryConfig) -> httpx.BaseTransport:
         if source.ca_certs:
